Page 108 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 108

Home

    are not going to be sent into any foreign wars."® When
    Tyler Kent, a code clerk at the American embassy in
    London, tried to reveal secret dispatches between
    Churchill and Roosevelt, and warn the American people
    of Roosevelt's intention of getting the United States into
    war, he was imprisoned in England until the war was
    over. By that time Roosevelt was dead.

    The power behind Roosevelt getting the United States
    into World War II was the Council on Foreign Relations.
    Under a program financed by the Rockefeller

    Under

    financed

    Under a program financed by the Rockefeller
    Foundation, (the War and Peace Studies Project) the
    CFR conducted 362 meetings and prepared 682 papers
    for the President and the State Department. This CFR

    the

    campaign was conducted in secret, and began just two
    weeks after Britain and France declared war on

    war on

    Germany.
    In 1940, CFR members ran an appeal for United

    States entry into the war in newspapers across the
    country. Their plan was for a union of the United States
    and England into a permanent Atlantic alliance as a
    major step toward world government.

    While America's secret government wanted war, the
    American people did not. In 1940, a Gallup poll found
    that 83 percent of Americans were against going to war

    in Europe.

    Ignoring the desires of the American people, and
    without a declaration of war by Congress, Roosevelt
    began to provoke Germany and the Axis powers by
    aiding Britain with fifty destroyers and hundreds of

    103

    Building Modern Babylon